@@ -3,7 +3,7 @@ from unittest import TestCase
 
 from pydantic.types import UUID
 
-from python_sdk.models.application import Application
+from oc_python_sdk.models.application import Application
 
 from ._helpers import get_application_data
 
